@@ -12,7 +12,7 @@ from typing import Self
 from ase.optimize import FIRE
 
 from rdkit import Chem
-from rdkit.Chem import rdMolTransforms, rdmolops
+from rdkit.Chem import rdMolTransforms, rdmolops, rdFreeSASA
 from PIL import Image
 
 from rdworks.std import clean_2d
@@ -24,6 +24,10 @@ from rdworks.view import render_png, render_svg
 
 import rdworks.utils
 
+
+ptable = Chem.GetPeriodicTable()
+
+
 class Conf:
     """Container for 3D conformers."""
     
@@ -56,8 +60,7 @@ class Conf:
         # Spin Multiplicity (2S + 1)
         # 0 unpaired electron  has S = 0,   2S + 1 = 0, called a singlet. 
         # 1 unpaired electron  has S = 1/2, 2S + 1 = 2, called a doublet (radical). 
-        # 2 unpaired electrons has S = 1,   2S + 1 = 3, called a triplet.  
-        
+        # 2 unpaired electrons has S = 1,   2S + 1 = 3, called a triplet.
         self.props = {}
 
         if molecule is None:
@@ -88,8 +91,14 @@ class Conf:
         assert num_atoms == tot_atoms, "Conf() Error: missing hydrogens"
         self.natoms = num_atoms
         self.charge = rdmolops.GetFormalCharge(self.rdmol)
-        self.props.update({'atoms': self.natoms, 'charge': self.charge})
+        self.set_solvent_accessible_surface_area()
+        self.props.update({
+            'atoms': self.natoms, 
+            'charge': self.charge,
+            })
+        
         assert self.rdmol.GetConformer().Is3D(), "Conf() Error: not 3D"
+        
 
 
     def __str__(self) -> str:
@@ -235,6 +244,44 @@ class Conf:
         
         return self
 
+    
+    def set_solvent_accessible_surface_area(self) -> None:
+        """Calculate Solvent Accessible Surface Area (total, polar, apolar).
+
+        Returns:
+            tuple[float, float, float]: (total, polar, apolar)
+        """
+        radii = [ptable.GetRvdw(atom.GetAtomicNum()) for atom in self.rdmol.GetAtoms()]
+        
+         # CalcSASA signature: CalcSASA(mol, radii, confId=conf_id) in modern RDKit
+        total_sasa = rdFreeSASA.CalcSASA(self.rdmol, radii=radii, confIdx=-1)
+
+        # try to read per-atom SASA values set by CalcSASA into atoms
+        atom_sasas = [atom.GetDoubleProp('SASA') for atom in self.rdmol.GetAtoms()]
+        
+        # Now compute polar/apolar sums: polar = N,O and Hs attached to them
+        polar_idx = set()
+        for atom in self.rdmol.GetAtoms():
+            if atom.GetAtomicNum() in (7, 8):  # N or O
+                polar_idx.add(atom.GetIdx())
+                # include attached hydrogens
+                for nbr in atom.GetNeighbors():
+                    if nbr.GetAtomicNum() == 1:
+                        polar_idx.add(nbr.GetIdx())
+
+        # default numeric 0 for None entries (defensive)
+        numeric_atom_sasas = [0.0 if v is None else float(v) for v in atom_sasas]
+        sasa_polar = sum(numeric_atom_sasas[i] for i in polar_idx)
+        sasa_total = sum(numeric_atom_sasas)
+        sasa_apolar = sasa_total - sasa_polar
+
+        self.props.update({
+            'sasa_total': sasa_total,
+            'sasa_polar': sasa_polar,
+            'sasa_apolar': sasa_apolar,
+        })
+
+
 
     def get_torsion_angle_atoms(self, strict: bool = True) -> list[tuple]:
         """Determine torsion/dihedral angle atoms (i-j-k-l) and rotating group for each rotatable bond (j-k).
